#!/usr/bin/python3

import sys
from openbabel import *
from ElectrostaticTools import *
import os
import math

mglroot="/usr/lib/python2.7/site-packages/MGLToolsPckgs/"

if ( len(sys,argv) != 3 ):
  print("Usage: get_XB_params.py <pdbbind_dir> <pdb_code>\n")
  sys.exit()

libdir = sys.argv[1]
cmplx = sys.argv[2]

mol = OBMol()
prot = OBMol()
conv = OBConversion()
conv.SetInFormat("MOL2")
conv.ReadFile(mol, libdir+"/"+cmplx+"/"+cmplx+"_ligand.mol2")
conv.SetInFormat("PDB")
conv.ReadFile(prot, libdir+"/"+cmplx+"/"+cmplx+"_protein.pdb")

amide = OBSmartsPattern()
amide.Init("NC=O")

smarts_o = ["O", "OC", "O(C)C", "[O-]C", "Oc", "[O-]c", "OC=O", "O=C"]
smarts_n = ["N", "[NH3]", "[N+]", "NC=O", "n", "n~c~n", "N~C~N"]
smarts_s = ["S", "SC", "S(C)C", "SS"]

halogen = ""
atom = ""
pattern = ""

for hal in OBMolAtomIter(mol):
  max_dist = 10
  if ( hal.GetAtomicNum() == 17 ):
    max_dist = 5.0
    halogen = "Cl"
  elif ( hal.GetAtomicNum() == 35 ):
    max_dist = 5.0
    halogen = "Br"
  elif ( hal.GetAtomicNum() == 53 ):
    max_dist = 5.0
    halogen = "I"
  elif ( hal.GetAtomicNum() == 9 ):
    max_dist = 5.0
    halogen = "F"
  if ( max_dist < 10 ) :
    nbr = OBAtom()
    for k in OBAtomAtomIter(hal) :
      nbr = k
      break
    for donor in OBMolAtomIter(prot):
      donor_z = donor.GetAtomicNum()
      if ( donor_z == 8 or donor_z == 7 or donor_z == 16 ):
        distance = hal.GetDistance(donor)
        if ( distance < max_dist ):
          angle = 0      
          v = nbr.GetVector()
          nbr_v = Vector3(v.GetX(), v.GetY(), v.GetZ())
          v = hal.GetVector()
          hal_v = Vector3(v.GetX(), v.GetY(), v.GetZ())
          v = donor.GetVector()
          donor_v = Vector3(v.GetX(), v.GetY(), v.GetZ())
          v1 = nbr_v - hal_v
          v2 = donor_v - hal_v
          angle = math.acos(v1.dot(v2)/v1.length()/v2.length())/math.pi*180.0                           
          if (donor_z == 8):
            atom = "O"
            pattern = ""
            for s in smarts_o:
              if ( donor.MatchesSMARTS(s) ):
                pattern = s
          if (donor_z == 7):
            atom = "N"
            pattern = ""
            for s in smarts_n:
              if ( donor.MatchesSMARTS(s) ):
                pattern = s
          if (donor_z == 16):
            atom = "S"
            pattern = ""
            for s in smarts_s:
              if ( donor.MatchesSMARTS(s) ):
                pattern = s
          print(cmplx+" "+halogen+" "+atom+" "+str(distance)+" "+str(angle)+" "+pattern)


