#!/bin/bash

#export ADT_ROOT="/usr/lib/python2.7/site-packages/MGLToolsPckgs/AutoDockTools/Utilities24/"

if [[ -v ADT_ROOT ]]
then
  ${ADT_ROOT}="${ADT_ROOT}/"
fi

export GRID_SPACING="0.1875"

SCRIPT_DIR=$(dirname "${BASH_SOURCE[0]}" )

if [ "$#" -lt 3 ]; then
  echo "Usage prepare.sh <libdir> <mcc/normal> <list_of_pdb_codes>"
  exit
fi

libdir=$1
shift
t=$1
shift

while (( "$#" ))
do
  cmplx=$1
  echo "-----------------------------"
  echo ${cmplx}
  echo "-----------------------------"
  mkdir ${cmplx}
  for grid in px py pz mx my mz 
  do 
    mkdir ${cmplx}/${grid}
  done
  cp ${libdir}/${cmplx}/${cmplx}_ligand.mol2 ${cmplx}/${cmplx}_ligand.mol2 
  cp ${libdir}/${cmplx}/${cmplx}_protein.pdb ${cmplx}/${cmplx}_protein.pdb
  
  ${SCRIPT_DIR}/prepare_ligand_${t}.py ${libdir} ${cmplx}
  ${SCRIPT_DIR}/fix_pdbqt.py ${cmplx}/${cmplx}_ligand.pdbqt
  ${SCRIPT_DIR}/clear_metal.py . ${cmplx}
  ${ADT_ROOT}prepare_receptor4.py -r ${cmplx}/${cmplx}_protein.pdb           \
                                   -o ${cmplx}/${cmplx}_protein.pdbqt         \
                                   -U nphs_lps_waters
  for grid in px py pz mx my mz 
  do 
    ln -sf ../${cmplx}_ligand.pdbqt ${cmplx}/${grid}/${cmplx}_ligand.pdbqt
    ln -sf ../${cmplx}_protein.pdbqt ${cmplx}/${grid}/${cmplx}_protein.pdbqt
  done
  ${SCRIPT_DIR}/prepare_box.py ${libdir} ${cmplx} 
  for grid in px py pz mx my mz
  do
    ${ADT_ROOT}prepare_dpf42.py -e -l ${cmplx}/${grid}/${cmplx}_ligand.pdbqt \
                                 -r ${cmplx}/${grid}/${cmplx}_protein.pdbqt   \
                                 -o ${cmplx}/${grid}/${cmplx}_docking.dpf 
    sed -i.bak 's|#| #|g' ${cmplx}/${grid}/${cmplx}_grid.gpf 
    sed -i.bak 's|#| #|g' ${cmplx}/${grid}/${cmplx}_docking.dpf 
  done
  shift
  echo "-----------------------------"
done

unset ADT_ROOT
unset GRID_SPACING
