#!/usr/bin/python3

import sys
from openbabel import *
import random
import time
import os

adtroot = os.getenv('ADT_ROOT', "")

spacing = float(os.getenv('GRID_SPACING', 0.1875))


libdir=""
cmplx=""

if ( len(sys.argv) == 3 ):
  libdir = sys.argv[1]
  cmplx = sys.argv[2]
elif ( len(sys.argv) == 4 ):
  spacing = sys.argv[3]
else  :
  print("Usage prepare_box.py <libdir> <pdb_code> [grid_spacing]\n")
  sys.exit()

mol = OBMol()
conv = OBConversion()
conv.SetInFormat("MOL2")
conv.ReadFile(mol, libdir+"/"+cmplx+"/"+cmplx+"_ligand.mol2")

magic_number = 99999.0
xmin = magic_number
xmax = -magic_number
ymin = magic_number
ymax = -magic_number
zmin = magic_number
zmax = -magic_number

for atom in OBMolAtomIter(mol):
  vec = atom.GetVector()
  x = vec.GetX()
  y = vec.GetY()
  z = vec.GetZ()
  if (xmin > x):
    xmin = x
  if (xmax < x):
    xmax = x
  if (ymin > y):
    ymin = y
  if (ymax < y):
    ymax = y
  if (zmin > z):
    zmin = z
  if (zmax < z):
    zmax = z

# increase the size of grid

xmin -= 5
ymin -= 5
zmin -= 5
xmax += 5
ymax += 5
zmax += 5

for i in ('x','y','z'):
  for j in ('p','m'):

    bxmin=xmin
    bxmax=xmax
    bymin=ymin
    bymax=ymax
    bzmin=zmin
    bzmax=zmax
    
    xmax += 5 if i == 'x' and j == 'p' else 0 
    xmin -= 5 if i == 'x' and j == 'm' else 0
    ymax += 5 if i == 'y' and j == 'p' else 0
    ymin -= 5 if i == 'y' and j == 'm' else 0
    zmax += 5 if i == 'z' and j == 'p' else 0 
    zmin -= 5 if i == 'z' and j == 'm' else 0

    xwidth=xmax-xmin
    ywidth=ymax-ymin
    zwidth=zmax-zmin

    if (xwidth < 22.5) :
      xmin -= (22.5-xwidth)/2.0
      xmax += (22.5-xwidth)/2.0
      xwidth=22.5
    if (ywidth < 22.5) :
      ymin -= (22.5-ywidth)/2.0
      ymax += (22.5-ywidth)/2.0
      ywidth=22.5
    if (zwidth < 22.5) :
      zmin -= (22.5-zwidth)/2.0
      zmax += (22.5-zwidth)/2.0
      zwidth=22.5

    # get grid center and number of points

    center = ((xmax+xmin)/2.0, (ymax+ymin)/2.0, (zmax+zmin)/2.0)
    npoints = ( round(xwidth/spacing), round(ywidth/spacing), round(zwidth/spacing) )

    os.system("python "+adtroot+"prepare_gpf4.py -l "+cmplx+"/"+j+i+"/"+cmplx+"_ligand.pdbqt -r "+
    cmplx+"/"+j+i+"/"+cmplx+"_protein.pdbqt -p gridcenter='"+
    str(center[0])+","+str(center[1])+","+str(center[2])+"' -p npts='"+
    str(npoints[0])+","+str(npoints[1])+","+str(npoints[2])+"' -p spacing='"+str(spacing)+"' -o "+
    cmplx+"/"+j+i+"/"+cmplx+"_grid.gpf")
