#!/usr/bin/python3

import sys
from openbabel import *
from ElectrostaticTools import *
import os

adtroot = os.getenv('ADT_ROOT', "")

if ( len(sys.argv) != 3 ):
  print("Usage: prepare_ligand.py <libdir> <pdb_code>")
  sys.exit()

libdir = sys.argv[1]
cmplx = sys.argv[2]


mol = GeneralMultipoledMolecule()
conv = OBConversion()
conv.SetInFormat("MOL2")
conv.ReadFile(mol, libdir+"/"+cmplx+"/"+cmplx+"_ligand.mol2")

freeze = []

pattern = OBSmartsPattern()
pattern.Init("[Cl,Br,I]")
pattern.Match(mol)
hits = pattern.GetMapList()

for i in hits:
  hal = mol.GetAtom(i[0])
  freeze.append(str(i[0] - 1))
  for nbr in OBAtomAtomIter(hal):
    if (nbr.GetAtomicNum != 0) :
      freeze.append(str(nbr.GetIdx() - 1))
      break

freeze_str = ""
if(len(freeze) > 0):
  freeze_str = " -I "+str("_").join(freeze)

cl_q = str(1.15/0.1406)
br_q = str(1.59/0.1406)
i_q  = str(2.76/0.1406)

os.system("mmol2mol "+cmplx+"/"+cmplx+"_ligand.mol2 "+cmplx+"/"+cmplx+"_ligand.mcc.mol2 -M \"[Cl,Br,I]\" -r 0.1 -f"+
                    " -Q\"[Cl] "+cl_q+"\" -Q\"[Br] "+br_q+"\" -Q\"[I] "+i_q+"\"")

os.system("python "+adtroot+"prepare_ligand4.py -l "+
cmplx+"/"+cmplx+"_ligand.mcc.mol2 -C -U \"nphs\""+freeze_str+" -o "+cmplx+"/"+cmplx+"_ligand.pdbqt" )
